"Main interface for iotanalytics service Client"
from datetime import datetime
import sys
from typing import Any, Dict, IO, List, Union, overload
from botocore.client import BaseClient
from botocore.exceptions import ClientError as Boto3ClientError

# pylint: disable=import-self
import mypy_boto3_iotanalytics.client as client_scope

# pylint: disable=import-self
import mypy_boto3_iotanalytics.paginator as paginator_scope
from mypy_boto3_iotanalytics.type_defs import (
    BatchPutMessageResponseTypeDef,
    ChannelStorageTypeDef,
    CreateChannelResponseTypeDef,
    CreateDatasetContentResponseTypeDef,
    CreateDatasetResponseTypeDef,
    CreateDatastoreResponseTypeDef,
    CreatePipelineResponseTypeDef,
    DatasetActionTypeDef,
    DatasetContentDeliveryRuleTypeDef,
    DatasetTriggerTypeDef,
    DatastoreStorageTypeDef,
    DescribeChannelResponseTypeDef,
    DescribeDatasetResponseTypeDef,
    DescribeDatastoreResponseTypeDef,
    DescribeLoggingOptionsResponseTypeDef,
    DescribePipelineResponseTypeDef,
    GetDatasetContentResponseTypeDef,
    ListChannelsResponseTypeDef,
    ListDatasetContentsResponseTypeDef,
    ListDatasetsResponseTypeDef,
    ListDatastoresResponseTypeDef,
    ListPipelinesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    LoggingOptionsTypeDef,
    MessageTypeDef,
    PipelineActivityTypeDef,
    RetentionPeriodTypeDef,
    RunPipelineActivityResponseTypeDef,
    SampleChannelDataResponseTypeDef,
    StartPipelineReprocessingResponseTypeDef,
    TagTypeDef,
    VersioningConfigurationTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("IoTAnalyticsClient",)


class IoTAnalyticsClient(BaseClient):
    """
    [IoTAnalytics.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client)
    """

    exceptions: client_scope.Exceptions

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def batch_put_message(
        self, channelName: str, messages: List[MessageTypeDef]
    ) -> BatchPutMessageResponseTypeDef:
        """
        [Client.batch_put_message documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.batch_put_message)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.can_paginate)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def cancel_pipeline_reprocessing(
        self, pipelineName: str, reprocessingId: str
    ) -> Dict[str, Any]:
        """
        [Client.cancel_pipeline_reprocessing documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.cancel_pipeline_reprocessing)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_channel(
        self,
        channelName: str,
        channelStorage: ChannelStorageTypeDef = None,
        retentionPeriod: RetentionPeriodTypeDef = None,
        tags: List[TagTypeDef] = None,
    ) -> CreateChannelResponseTypeDef:
        """
        [Client.create_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.create_channel)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_dataset(
        self,
        datasetName: str,
        actions: List[DatasetActionTypeDef],
        triggers: List[DatasetTriggerTypeDef] = None,
        contentDeliveryRules: List[DatasetContentDeliveryRuleTypeDef] = None,
        retentionPeriod: RetentionPeriodTypeDef = None,
        versioningConfiguration: VersioningConfigurationTypeDef = None,
        tags: List[TagTypeDef] = None,
    ) -> CreateDatasetResponseTypeDef:
        """
        [Client.create_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_dataset_content(self, datasetName: str) -> CreateDatasetContentResponseTypeDef:
        """
        [Client.create_dataset_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset_content)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_datastore(
        self,
        datastoreName: str,
        datastoreStorage: DatastoreStorageTypeDef = None,
        retentionPeriod: RetentionPeriodTypeDef = None,
        tags: List[TagTypeDef] = None,
    ) -> CreateDatastoreResponseTypeDef:
        """
        [Client.create_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.create_datastore)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_pipeline(
        self,
        pipelineName: str,
        pipelineActivities: List[PipelineActivityTypeDef],
        tags: List[TagTypeDef] = None,
    ) -> CreatePipelineResponseTypeDef:
        """
        [Client.create_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.create_pipeline)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_channel(self, channelName: str) -> None:
        """
        [Client.delete_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_channel)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_dataset(self, datasetName: str) -> None:
        """
        [Client.delete_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_dataset_content(self, datasetName: str, versionId: str = None) -> None:
        """
        [Client.delete_dataset_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset_content)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_datastore(self, datastoreName: str) -> None:
        """
        [Client.delete_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_datastore)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_pipeline(self, pipelineName: str) -> None:
        """
        [Client.delete_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_pipeline)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_channel(
        self, channelName: str, includeStatistics: bool = None
    ) -> DescribeChannelResponseTypeDef:
        """
        [Client.describe_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_channel)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_dataset(self, datasetName: str) -> DescribeDatasetResponseTypeDef:
        """
        [Client.describe_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_dataset)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_datastore(
        self, datastoreName: str, includeStatistics: bool = None
    ) -> DescribeDatastoreResponseTypeDef:
        """
        [Client.describe_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_datastore)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_logging_options(self) -> DescribeLoggingOptionsResponseTypeDef:
        """
        [Client.describe_logging_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_logging_options)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_pipeline(self, pipelineName: str) -> DescribePipelineResponseTypeDef:
        """
        [Client.describe_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_pipeline)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> None:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.generate_presigned_url)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_dataset_content(
        self, datasetName: str, versionId: str = None
    ) -> GetDatasetContentResponseTypeDef:
        """
        [Client.get_dataset_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.get_dataset_content)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_channels(
        self, nextToken: str = None, maxResults: int = None
    ) -> ListChannelsResponseTypeDef:
        """
        [Client.list_channels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.list_channels)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_dataset_contents(
        self,
        datasetName: str,
        nextToken: str = None,
        maxResults: int = None,
        scheduledOnOrAfter: datetime = None,
        scheduledBefore: datetime = None,
    ) -> ListDatasetContentsResponseTypeDef:
        """
        [Client.list_dataset_contents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.list_dataset_contents)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_datasets(
        self, nextToken: str = None, maxResults: int = None
    ) -> ListDatasetsResponseTypeDef:
        """
        [Client.list_datasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datasets)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_datastores(
        self, nextToken: str = None, maxResults: int = None
    ) -> ListDatastoresResponseTypeDef:
        """
        [Client.list_datastores documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datastores)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_pipelines(
        self, nextToken: str = None, maxResults: int = None
    ) -> ListPipelinesResponseTypeDef:
        """
        [Client.list_pipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.list_pipelines)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
        """
        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.list_tags_for_resource)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def put_logging_options(self, loggingOptions: LoggingOptionsTypeDef) -> None:
        """
        [Client.put_logging_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.put_logging_options)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def run_pipeline_activity(
        self, pipelineActivity: PipelineActivityTypeDef, payloads: List[Union[bytes, IO]]
    ) -> RunPipelineActivityResponseTypeDef:
        """
        [Client.run_pipeline_activity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.run_pipeline_activity)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def sample_channel_data(
        self,
        channelName: str,
        maxMessages: int = None,
        startTime: datetime = None,
        endTime: datetime = None,
    ) -> SampleChannelDataResponseTypeDef:
        """
        [Client.sample_channel_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.sample_channel_data)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def start_pipeline_reprocessing(
        self, pipelineName: str, startTime: datetime = None, endTime: datetime = None
    ) -> StartPipelineReprocessingResponseTypeDef:
        """
        [Client.start_pipeline_reprocessing documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.start_pipeline_reprocessing)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def tag_resource(self, resourceArn: str, tags: List[TagTypeDef]) -> Dict[str, Any]:
        """
        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.tag_resource)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
        """
        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.untag_resource)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_channel(
        self,
        channelName: str,
        channelStorage: ChannelStorageTypeDef = None,
        retentionPeriod: RetentionPeriodTypeDef = None,
    ) -> None:
        """
        [Client.update_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.update_channel)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_dataset(
        self,
        datasetName: str,
        actions: List[DatasetActionTypeDef],
        triggers: List[DatasetTriggerTypeDef] = None,
        contentDeliveryRules: List[DatasetContentDeliveryRuleTypeDef] = None,
        retentionPeriod: RetentionPeriodTypeDef = None,
        versioningConfiguration: VersioningConfigurationTypeDef = None,
    ) -> None:
        """
        [Client.update_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.update_dataset)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_datastore(
        self,
        datastoreName: str,
        retentionPeriod: RetentionPeriodTypeDef = None,
        datastoreStorage: DatastoreStorageTypeDef = None,
    ) -> None:
        """
        [Client.update_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.update_datastore)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_pipeline(
        self, pipelineName: str, pipelineActivities: List[PipelineActivityTypeDef]
    ) -> None:
        """
        [Client.update_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Client.update_pipeline)
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_channels"]
    ) -> paginator_scope.ListChannelsPaginator:
        """
        [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_dataset_contents"]
    ) -> paginator_scope.ListDatasetContentsPaginator:
        """
        [Paginator.ListDatasetContents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_datasets"]
    ) -> paginator_scope.ListDatasetsPaginator:
        """
        [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_datastores"]
    ) -> paginator_scope.ListDatastoresPaginator:
        """
        [Paginator.ListDatastores documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_pipelines"]
    ) -> paginator_scope.ListPipelinesPaginator:
        """
        [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
        """


class Exceptions:
    ClientError: Boto3ClientError
    InternalFailureException: Boto3ClientError
    InvalidRequestException: Boto3ClientError
    LimitExceededException: Boto3ClientError
    ResourceAlreadyExistsException: Boto3ClientError
    ResourceNotFoundException: Boto3ClientError
    ServiceUnavailableException: Boto3ClientError
    ThrottlingException: Boto3ClientError
